Package: report
Type: Package
Title: Automated Reporting of Results and Statistical Models
Version: 0.6.4
Authors@R: 
    c(person(given = "Dominique",
             family = "Makowski",
             role = "aut",
             email = "dom.makowski@gmail.com",
             comment = c(ORCID = "0000-0001-5375-9967")),
      person(given = "Daniel",
             family = "Lüdecke",
             role = "aut",
             email = "d.luedecke@uke.de",
             comment = c(ORCID = "0000-0002-8895-3206")),
      person(given = "Indrajeet",
             family = "Patil",
             role = "aut",
             email = "patilindrajeet.science@gmail.com",
             comment = c(ORCID = "0000-0003-1995-6531")),
      person(given = "Rémi",
             family = "Thériault",
             role = c("aut", "cre"),
             email = "remi.theriault@mail.mcgill.ca",
             comment = c(ORCID = "0000-0003-4315-6788")),
      person(given = "Mattan S.",
             family = "Ben-Shachar",
             role = "aut",
             email = "matanshm@post.bgu.ac.il",
             comment = c(ORCID = "0000-0002-4287-4801")),
      person(given = "Brenton M.",
             family = "Wiernik",
             role = "aut",
             email = "brenton@wiernik.org",
             comment = c(ORCID = "0000-0001-9560-6336")),
      person(given = "Rudolf",
             family = "Siegel",
             role = "ctb",
             email = "mutlusun@users.noreply.github.com",
             comment = c(ORCID = "0000-0002-6021-804X")),
     person(given = "Camden",
            family = "Bock",
            role = "ctb",
            email = "camden.bock@maine.edu",
            comment = c(ORCID = "0000-0002-3907-7748")))
Maintainer: Rémi Thériault <remi.theriault@mail.mcgill.ca>
Description: The aim of the 'report' package is to bridge the gap between
    R’s output and the formatted results contained in your manuscript.
    This package converts statistical models and data frames into textual
    reports suited for publication, ensuring standardization and quality
    in results reporting.
License: MIT + file LICENSE
URL: https://easystats.github.io/report/
BugReports: https://github.com/easystats/report/issues
Depends: R (>= 3.6)
Imports: bayestestR (>= 0.17.0), effectsize (>= 1.0.2), insight (>=
        1.4.6), parameters (>= 0.28.3), performance (>= 0.16.0),
        datawizard (>= 1.3.0), stats, tools, utils
Suggests: BayesFactor, brms, collapse, GLMMadaptive, glmmTMB, ivreg,
        knitr, lavaan, lme4, loo, nlme, dplyr, Formula, rmarkdown,
        rstanarm, survival, modelbased (>= 0.9.0), emmeans,
        marginaleffects (>= 0.25.0), RcppEigen, BH, testthat (>= 3.2.1)
VignetteBuilder: knitr
Encoding: UTF-8
Language: en-US
Config/testthat/edition: 3
Config/Needs/website: rstudio/bslib, r-lib/pkgdown,
        easystats/easystatstemplate
Collate: 'cite_easystats.R' 'format_algorithm.R' 'format_citation.R'
        'format_formula.R' 'format_model.R' 'reexports.R'
        'report-package.R' 'report.BFBayesFactor.R'
        'utils_combine_tables.R' 'report.lm.R' 'report.MixMod.R'
        'report_text.R' 'report.R' 'report.htest.R' 'report.aov.R'
        'report.bayesfactor_models.R' 'report.lme4.R'
        'report.stanreg.R' 'report.brmsfit.R' 'report.character.R'
        'report.compare.loo.R' 'report.compare_performance.R'
        'report.coxph.R' 'report.data.frame.R' 'report.default.R'
        'report.estimate_contrasts.R' 'report.factor.R' 'report.glm.R'
        'report.glmmTMB.R' 'report.ivreg.R' 'report.lavaan.R'
        'report.lme.R' 'report.numeric.R' 'report.sessionInfo.R'
        'report.survreg.R' 'report.test_performance.R'
        'report.zeroinfl.R' 'report_effectsize.R' 'report_htest_chi2.R'
        'report_htest_cor.R' 'report_htest_fisher.R'
        'report_htest_friedman.R' 'report_htest_kruskal.R'
        'report_htest_ttest.R' 'report_htest_wilcox.R' 'report_info.R'
        'report_intercept.R' 'report_misc.R' 'report_model.R'
        'report_parameters.R' 'report_participants.R'
        'report_performance.R' 'report_priors.R' 'report_random.R'
        'report_s.R' 'report_sample.R' 'report_statistics.R'
        'report_table.R' 'utils_error_message.R' 'utils_grouped_df.R'
        'utils_misspelled_variables.R' 'zzz.R'
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-04 17:38:21 UTC; rt3105
Author: Dominique Makowski [aut] (ORCID:
    <https://orcid.org/0000-0001-5375-9967>),
  Daniel Lüdecke [aut] (ORCID: <https://orcid.org/0000-0002-8895-3206>),
  Indrajeet Patil [aut] (ORCID: <https://orcid.org/0000-0003-1995-6531>),
  Rémi Thériault [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4315-6788>),
  Mattan S. Ben-Shachar [aut] (ORCID:
    <https://orcid.org/0000-0002-4287-4801>),
  Brenton M. Wiernik [aut] (ORCID:
    <https://orcid.org/0000-0001-9560-6336>),
  Rudolf Siegel [ctb] (ORCID: <https://orcid.org/0000-0002-6021-804X>),
  Camden Bock [ctb] (ORCID: <https://orcid.org/0000-0002-3907-7748>)
Repository: CRAN
Date/Publication: 2026-05-04 21:10:12 UTC
Built: R 4.6.0; ; 2026-05-05 00:11:18 UTC; unix
