# Generated by roxygen2: do not edit by hand

S3method(as.character,report_parameters)
S3method(as.data.frame,report)
S3method(as.report_table,default)
S3method(as.report_table,report)
S3method(as.report_text,default)
S3method(as.report_text,report)
S3method(c,report_table)
S3method(display,report_table)
S3method(format,report_table)
S3method(format_model,character)
S3method(format_model,default)
S3method(print,cite_easystats)
S3method(print,report)
S3method(print,report_effectsize)
S3method(print,report_info)
S3method(print,report_intercept)
S3method(print,report_model)
S3method(print,report_parameters)
S3method(print,report_performance)
S3method(print,report_priors)
S3method(print,report_random)
S3method(print,report_sample)
S3method(print,report_statistics)
S3method(print,report_table)
S3method(print,report_text)
S3method(print_html,report_sample)
S3method(print_md,report_sample)
S3method(report,BFBayesFactor)
S3method(report,Date)
S3method(report,MixMod)
S3method(report,anova)
S3method(report,aov)
S3method(report,aovlist)
S3method(report,bayesfactor_inclusion)
S3method(report,bayesfactor_models)
S3method(report,brmsfit)
S3method(report,character)
S3method(report,compare.loo)
S3method(report,compare_performance)
S3method(report,coxph)
S3method(report,data.frame)
S3method(report,default)
S3method(report,estimate_contrasts)
S3method(report,factor)
S3method(report,glm)
S3method(report,glmmTMB)
S3method(report,grouped_df)
S3method(report,htest)
S3method(report,ivreg)
S3method(report,lavaan)
S3method(report,lm)
S3method(report,lme)
S3method(report,logical)
S3method(report,merMod)
S3method(report,numeric)
S3method(report,sessionInfo)
S3method(report,stanreg)
S3method(report,survreg)
S3method(report,test_performance)
S3method(report,zeroinfl)
S3method(report_effectsize,MixMod)
S3method(report_effectsize,anova)
S3method(report_effectsize,aov)
S3method(report_effectsize,aovlist)
S3method(report_effectsize,brmsfit)
S3method(report_effectsize,coxph)
S3method(report_effectsize,default)
S3method(report_effectsize,glm)
S3method(report_effectsize,glmmTMB)
S3method(report_effectsize,htest)
S3method(report_effectsize,ivreg)
S3method(report_effectsize,lm)
S3method(report_effectsize,lme)
S3method(report_effectsize,merMod)
S3method(report_effectsize,stanreg)
S3method(report_effectsize,survreg)
S3method(report_effectsize,zeroinfl)
S3method(report_info,MixMod)
S3method(report_info,anova)
S3method(report_info,aov)
S3method(report_info,aovlist)
S3method(report_info,brmsfit)
S3method(report_info,coxph)
S3method(report_info,default)
S3method(report_info,glm)
S3method(report_info,glmmTMB)
S3method(report_info,htest)
S3method(report_info,ivreg)
S3method(report_info,lm)
S3method(report_info,lme)
S3method(report_info,merMod)
S3method(report_info,stanreg)
S3method(report_info,survreg)
S3method(report_info,zeroinfl)
S3method(report_intercept,MixMod)
S3method(report_intercept,brmsfit)
S3method(report_intercept,coxph)
S3method(report_intercept,default)
S3method(report_intercept,glm)
S3method(report_intercept,glmmTMB)
S3method(report_intercept,ivreg)
S3method(report_intercept,lm)
S3method(report_intercept,lme)
S3method(report_intercept,merMod)
S3method(report_intercept,stanreg)
S3method(report_intercept,survreg)
S3method(report_intercept,zeroinfl)
S3method(report_model,MixMod)
S3method(report_model,anova)
S3method(report_model,aov)
S3method(report_model,aovlist)
S3method(report_model,brmsfit)
S3method(report_model,coxph)
S3method(report_model,default)
S3method(report_model,glm)
S3method(report_model,glmmTMB)
S3method(report_model,htest)
S3method(report_model,ivreg)
S3method(report_model,lm)
S3method(report_model,lme)
S3method(report_model,merMod)
S3method(report_model,stanreg)
S3method(report_model,survreg)
S3method(report_model,zeroinfl)
S3method(report_parameters,Date)
S3method(report_parameters,MixMod)
S3method(report_parameters,anova)
S3method(report_parameters,aov)
S3method(report_parameters,aovlist)
S3method(report_parameters,brmsfit)
S3method(report_parameters,character)
S3method(report_parameters,compare_performance)
S3method(report_parameters,coxph)
S3method(report_parameters,data.frame)
S3method(report_parameters,default)
S3method(report_parameters,factor)
S3method(report_parameters,glm)
S3method(report_parameters,glmmTMB)
S3method(report_parameters,grouped_df)
S3method(report_parameters,htest)
S3method(report_parameters,ivreg)
S3method(report_parameters,lm)
S3method(report_parameters,lme)
S3method(report_parameters,logical)
S3method(report_parameters,merMod)
S3method(report_parameters,numeric)
S3method(report_parameters,sessionInfo)
S3method(report_parameters,stanreg)
S3method(report_parameters,survreg)
S3method(report_parameters,test_performance)
S3method(report_parameters,zeroinfl)
S3method(report_performance,MixMod)
S3method(report_performance,brmsfit)
S3method(report_performance,coxph)
S3method(report_performance,default)
S3method(report_performance,glm)
S3method(report_performance,glmmTMB)
S3method(report_performance,ivreg)
S3method(report_performance,lavaan)
S3method(report_performance,lm)
S3method(report_performance,lme)
S3method(report_performance,merMod)
S3method(report_performance,stanreg)
S3method(report_performance,survreg)
S3method(report_performance,zeroinfl)
S3method(report_priors,brmsfit)
S3method(report_priors,default)
S3method(report_priors,stanreg)
S3method(report_random,MixMod)
S3method(report_random,brmsfit)
S3method(report_random,default)
S3method(report_random,glmmTMB)
S3method(report_random,lme)
S3method(report_random,merMod)
S3method(report_random,stanreg)
S3method(report_statistics,BFBayesFactor)
S3method(report_statistics,Date)
S3method(report_statistics,MixMod)
S3method(report_statistics,anova)
S3method(report_statistics,aov)
S3method(report_statistics,aovlist)
S3method(report_statistics,brmsfit)
S3method(report_statistics,character)
S3method(report_statistics,compare_performance)
S3method(report_statistics,coxph)
S3method(report_statistics,data.frame)
S3method(report_statistics,default)
S3method(report_statistics,factor)
S3method(report_statistics,glm)
S3method(report_statistics,glmmTMB)
S3method(report_statistics,grouped_df)
S3method(report_statistics,htest)
S3method(report_statistics,ivreg)
S3method(report_statistics,lm)
S3method(report_statistics,lme)
S3method(report_statistics,merMod)
S3method(report_statistics,numeric)
S3method(report_statistics,stanreg)
S3method(report_statistics,survreg)
S3method(report_statistics,test_performance)
S3method(report_statistics,zeroinfl)
S3method(report_table,Date)
S3method(report_table,MixMod)
S3method(report_table,anova)
S3method(report_table,aov)
S3method(report_table,aovlist)
S3method(report_table,bayesfactor_inclusion)
S3method(report_table,bayesfactor_models)
S3method(report_table,brmsfit)
S3method(report_table,character)
S3method(report_table,compare_performance)
S3method(report_table,coxph)
S3method(report_table,data.frame)
S3method(report_table,default)
S3method(report_table,estimate_contrasts)
S3method(report_table,factor)
S3method(report_table,glm)
S3method(report_table,glmmTMB)
S3method(report_table,grouped_df)
S3method(report_table,htest)
S3method(report_table,ivreg)
S3method(report_table,lavaan)
S3method(report_table,lm)
S3method(report_table,lme)
S3method(report_table,logical)
S3method(report_table,merMod)
S3method(report_table,numeric)
S3method(report_table,sessionInfo)
S3method(report_table,stanreg)
S3method(report_table,survreg)
S3method(report_table,test_performance)
S3method(report_table,zeroinfl)
S3method(report_text,Date)
S3method(report_text,MixMod)
S3method(report_text,anova)
S3method(report_text,aov)
S3method(report_text,aovlist)
S3method(report_text,bayesfactor_inclusion)
S3method(report_text,bayesfactor_models)
S3method(report_text,brmsfit)
S3method(report_text,character)
S3method(report_text,compare_performance)
S3method(report_text,coxph)
S3method(report_text,data.frame)
S3method(report_text,default)
S3method(report_text,estimate_contrasts)
S3method(report_text,factor)
S3method(report_text,glm)
S3method(report_text,glmmTMB)
S3method(report_text,grouped_df)
S3method(report_text,htest)
S3method(report_text,ivreg)
S3method(report_text,lm)
S3method(report_text,lme)
S3method(report_text,logical)
S3method(report_text,merMod)
S3method(report_text,numeric)
S3method(report_text,sessionInfo)
S3method(report_text,stanreg)
S3method(report_text,survreg)
S3method(report_text,test_performance)
S3method(report_text,zeroinfl)
S3method(summary,cite_easystats)
S3method(summary,report_effectsize)
S3method(summary,report_info)
S3method(summary,report_intercept)
S3method(summary,report_model)
S3method(summary,report_parameters)
S3method(summary,report_performance)
S3method(summary,report_priors)
S3method(summary,report_random)
S3method(summary,report_statistics)
S3method(summary,report_table)
S3method(summary,report_text)
export(as.report)
export(as.report_effectsize)
export(as.report_info)
export(as.report_intercept)
export(as.report_model)
export(as.report_parameters)
export(as.report_performance)
export(as.report_priors)
export(as.report_random)
export(as.report_statistics)
export(as.report_table)
export(as.report_text)
export(cite_citation)
export(cite_easystats)
export(cite_packages)
export(clean_citation)
export(display)
export(format_algorithm)
export(format_citation)
export(format_formula)
export(format_model)
export(is.report)
export(print_html)
export(print_md)
export(report)
export(report_date)
export(report_effectsize)
export(report_info)
export(report_intercept)
export(report_model)
export(report_packages)
export(report_parameters)
export(report_participants)
export(report_performance)
export(report_priors)
export(report_random)
export(report_s)
export(report_sample)
export(report_statistics)
export(report_story)
export(report_system)
export(report_table)
export(report_text)
importFrom(insight,display)
importFrom(insight,print_html)
importFrom(insight,print_md)
