#' \code{report-package}
#'
#' @title report: Automated Results Reporting as a Practical Tool to Improve
#' Reproducibility and Methodological Best Practices Adoption
#'
#' @description
#'
#' **report**’s primary goal is to bridge the gap between R’s output and
#' the formatted results contained in your manuscript. It automatically produces
#' reports of models and data frames according to **best practices** guidelines
#' (e.g., [APA](https://apastyle.apa.org/)’s style), ensuring **standardization**
#' and **quality** in results reporting.
#'
#' @docType package
#' @aliases report-package
#' @name report-package
#' @keywords internal
"_PACKAGE"
