# report_performance Bayesian)

    Code
      report_performance(x5)
    Output
      The model's explanatory power is substantial (R2 = 0.62, 95% CI [0.53, 0.69],
      adj. R2 = 0.61)

---

    Code
      summary(report_performance(x5))
    Output
      [1] "The model's explanatory power is substantial (R2 = 0.62, adj. R2 = 0.61)"

---

    Code
      report_performance(x6)
    Output
      The model's explanatory power is substantial (R2 = 0.54, 95% CI [0.27, 0.77])

---

    Code
      summary(report_performance(x6))
    Output
      [1] "The model's explanatory power is substantial (R2 = 0.54)"

# report_performance Bayesian 2)

    Code
      summary(report_performance(x7))
    Output
      [1] "The model's explanatory power is substantial (R2 = 0.83, adj. R2 = 0.83) and the part related to the fixed effects alone (marginal R2) is of 0.74"

