# report.htest-kruskal report

    Code
      report(x, verbose = FALSE)
    Output
      Effect sizes were labelled following Field's (2013) recommendations.
      
      The Kruskal-Wallis rank sum test testing the difference in ranks between
      airquality$Ozone and as.factor(airquality$Month) suggests that the effect is
      statistically significant, and large (Kruskal-Wallis chi2 = 29.27, p < .001;
      Epsilon squared (rank) = 0.25, 95% CI [0.15, 1.00])

