% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/report_text.R, R/report.R,
%   R/report_effectsize.R, R/report_info.R, R/report_intercept.R,
%   R/report_model.R, R/report_parameters.R, R/report_performance.R,
%   R/report_priors.R, R/report_random.R, R/report_statistics.R,
%   R/report_table.R
\name{as.report_text}
\alias{as.report_text}
\alias{as.report}
\alias{is.report}
\alias{as.report_effectsize}
\alias{as.report_info}
\alias{as.report_intercept}
\alias{as.report_model}
\alias{as.report_parameters}
\alias{as.report_performance}
\alias{as.report_priors}
\alias{as.report_random}
\alias{as.report_statistics}
\alias{as.report_table}
\title{Create or test objects of class \link{report}.}
\usage{
as.report_text(x, ...)

as.report(text, table = NULL, plot = NULL, ...)

is.report(x)

as.report_effectsize(x, summary = NULL, prefix = "  - ", ...)

as.report_info(x, summary = NULL, ...)

as.report_intercept(x, summary = NULL, ...)

as.report_model(x, summary = NULL, ...)

as.report_parameters(x, summary = NULL, prefix = "  - ", ...)

as.report_performance(x, summary = NULL, ...)

as.report_priors(x, summary = NULL, ...)

as.report_random(x, summary = NULL, ...)

as.report_statistics(x, summary = NULL, prefix = "  - ", ...)

as.report_table(x, ...)
}
\arguments{
\item{x}{An arbitrary R object.}

\item{...}{Args to be saved as attributes.}

\item{text}{Text obtained via \code{report_text()}}

\item{table}{Table obtained via \code{report_table()}}

\item{plot}{Plot obtained via \code{report_plot()}. Not yet implemented.}

\item{summary}{Add a summary as attribute (to be extracted via \code{summary()}).}

\item{prefix}{The prefix to be displayed in front of each parameter.}
}
\value{
A report object or a \code{TRUE/FALSE} value.
}
\description{
Allows to create or test whether an object is of the \code{report} class.
}
